@@ -3,6 +3,7 @@
 
 from typing import Any
 from typing import Optional
+from typing import Union
 
 from apyscript.display.begin_fill_interface import BiginFillInterface
 from apyscript.display.child_interface import ChildInterface
@@ -69,7 +70,10 @@ class Graphics(
         expression_file_util.append_expression(expression=expression)
 
     def draw_rect(
-            self, x: int, y: int, width: int, height: int) -> Rectangle:
+            self, x: Union[int, Int],
+            y: Union[int, Int],
+            width: Union[int, Int],
+            height: Union[int, Int]) -> Rectangle:
         """
         Draw rectangle vector graphics.
 
